@@ -13,4 +13,4 @@ enc = clam.common.oauth.encrypt(OAUTH_ENCRYPTIONSECRET,token,ip)
 
 dec,ip = clam.common.oauth.decrypt(OAUTH_ENCRYPTIONSECRET,enc)
 
-print dec, ip
+print(dec, ip)
